package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcBorrowDetail;

/**
 * cmc借款明细Mapper接口
 * 
 * @author cmc
 * @date 2024-04-07
 */
public interface CmcBorrowDetailMapper 
{
    /**
     * 查询cmc借款明细
     * 
     * @param borrowId cmc借款明细主键
     * @return cmc借款明细
     */
    public List<CmcBorrowDetail> selectCmcBorrowDetailByBorrowId(String borrowId);

    /**
     * 查询cmc借款明细列表
     * 
     * @param cmcBorrowDetail cmc借款明细
     * @return cmc借款明细集合
     */
    public List<CmcBorrowDetail> selectCmcBorrowDetailList(CmcBorrowDetail cmcBorrowDetail);

    /**
     * 新增cmc借款明细
     * 
     * @param cmcBorrowDetail cmc借款明细
     * @return 结果
     */
    public int insertCmcBorrowDetail(CmcBorrowDetail cmcBorrowDetail);

    /**
     * 修改cmc借款明细
     * 
     * @param cmcBorrowDetail cmc借款明细
     * @return 结果
     */
    public int updateCmcBorrowDetail(CmcBorrowDetail cmcBorrowDetail);

    /**
     * 删除cmc借款明细
     * 
     * @param borrowId cmc借款明细主键
     * @return 结果
     */
    public int deleteCmcBorrowDetailByBorrowId(String borrowId);

    /**
     * 批量删除cmc借款明细
     * 
     * @param borrowIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcBorrowDetailByBorrowIds(String[] borrowIds);

    /**
     * 批量删除cmc借款明细
     *
     * @param borrowIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcBorrowDetailByBorrowDetailId(String[] borrowDetailId);
}
